@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ class About : public QDialog, public Ui::About
 	Q_OBJECT
 
 public:
-	About( QWidget * parent = 0, Qt::WindowFlags f = 0 );
+	About( QWidget * parent = 0, Qt::WindowFlags f = QFlag(0) );
 	~About();
 
 	virtual QSize sizeHint () const;
