@@ -47,7 +47,6 @@
 #endif
 
 #ifdef SCREENS_SUPPORT
-#include <QVBoxLayout>
 #include <QLabel>
 #include "mplayerwindow.h"
 #include "infowindow.h"
@@ -56,7 +55,11 @@
 #include <QScreen>
 #include <QWindow>
 #endif
+
+#ifdef DETACH_VIDEO_LAYER
+#include <QVBoxLayout>
 #endif
+#endif // SCREENS_SUPPORT
 
 #ifdef GLOBALSHORTCUTS
 #include "globalshortcuts/globalshortcuts.h"
@@ -160,7 +163,7 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
                 showPlaylistAct, SLOT(setChecked(bool)) );
 	}
 
-#ifdef DETACH_VIDEO_OPTION
+#if defined(DETACH_VIDEO_LAYER) && defined(DETACH_VIDEO_OPTION)
 	detachVideoAct = new MyAction(this, "detach_video");
 	detachVideoAct->setCheckable(true);
 	connect(detachVideoAct, SIGNAL(toggled(bool)), this, SLOT(detachVideo(bool)));
@@ -270,7 +273,7 @@ void BaseGuiPlus::populateMainMenu() {
 		#endif
 	}
 
-#ifdef DETACH_VIDEO_OPTION
+#if defined(DETACH_VIDEO_LAYER) && defined(DETACH_VIDEO_OPTION)
 	optionsMenu->addAction(detachVideoAct);
 #endif
 
@@ -375,7 +378,7 @@ void BaseGuiPlus::retranslateStrings() {
 	updateShowAllAct();
 #endif
 
-#ifdef DETACH_VIDEO_OPTION
+#if defined(DETACH_VIDEO_LAYER) && defined(DETACH_VIDEO_OPTION)
 	detachVideoAct->change("Detach video");
 #endif
 
@@ -1017,20 +1020,31 @@ void BaseGuiPlus::updateSendToScreen() {
 
 	sendToScreen_menu->clear();
 	sendToScreen_menu->addActions(sendToScreenGroup->actions());
-	
+
+#ifdef DETACH_VIDEO_LAYER
 	if (n_screens == 1 && isVideoDetached()) detachVideo(false);
+#endif
 }
 
 void BaseGuiPlus::sendVideoToScreen(int screen) {
 	qDebug() << "BaseGuiPlus::sendVideoToScreen:" << screen;
 
-#if QT_VERSION >= 0x050000
+#ifndef DETACH_VIDEO_LAYER
+	if (core->displayScreen() == screen) return;
+
+	mplayerwindow->setVisible(screen == 0);
+	detached_label->setVisible(screen != 0);
+	fullscreenAct->setEnabled(screen == 0);
+	core->setDisplayScreen(screen);
+	core->restart();
+#else
+	#if QT_VERSION >= 0x050000
 	QList<QScreen *> screen_list = qApp->screens();
 	int n_screens = screen_list.count();
-#else
+	#else
 	QDesktopWidget * dw = qApp->desktop();
 	int n_screens = dw->screenCount();
-#endif
+	#endif
 
 	if (screen < n_screens) {
 		#if QT_VERSION >= 0x050000
@@ -1064,10 +1078,14 @@ void BaseGuiPlus::sendVideoToScreen(int screen) {
 		// Error
 		qWarning() << "BaseGuiPlus::sendVideoToScreen: screen" << screen << "is not valid";
 	}
+#endif
 }
+#endif // SCREENS_SUPPORT
 
+#ifdef DETACH_VIDEO_LAYER
 bool BaseGuiPlus::isVideoDetached() {
-	return (mplayerwindow->parent() == 0);
+	//return (mplayerwindow->parent() == 0);
+	return (mplayerwindow->windowFlags() & Qt::Window);
 }
 
 void BaseGuiPlus::detachVideo(bool detach) {
@@ -1079,7 +1097,8 @@ void BaseGuiPlus::detachVideo(bool detach) {
 			fullscreenAct->setEnabled(false);
 
 			panel->layout()->removeWidget(mplayerwindow);
-			mplayerwindow->setParent(0);
+			//mplayerwindow->setParent(0);
+			mplayerwindow->setWindowFlags(Qt::Window);
 			mplayerwindow->setWindowTitle(tr("SMPlayer external screen output"));
 
 			detached_label->show();
@@ -1092,7 +1111,8 @@ void BaseGuiPlus::detachVideo(bool detach) {
 			detached_label->hide();
 
 			mplayerwindow->setWindowTitle(QString());
-			mplayerwindow->setParent(panel);
+			//mplayerwindow->setParent(panel);
+			mplayerwindow->setWindowFlags(Qt::Widget);
 			#if QT_VERSION >= 0x050000 && defined(OS_UNIX_NOT_MAC)
 			qApp->processEvents();
 			#endif
@@ -1134,7 +1154,12 @@ void BaseGuiPlus::updateSendAudioMenu() {
 	sendAudio_menu->addAction(a);
 
 #if USE_PULSEAUDIO_DEVICES
-	addListToSendAudioMenu( DeviceInfo::paDevices(), "pulse");
+	#if USE_MPV_PULSE_DEVICES
+	if (PlayerID::player(pref->mplayer_bin) == PlayerID::MPLAYER)
+	#endif
+	{
+		addListToSendAudioMenu( DeviceInfo::paDevices(), "pulse");
+	}
 #endif
 
 #if USE_ALSA_DEVICES
@@ -1155,9 +1180,17 @@ void BaseGuiPlus::updateSendAudioMenu() {
 		addListToSendAudioMenu( DeviceInfo::mpvAlsaDevices(), "alsa");
 		#endif
 
+		#if USE_MPV_PULSE_DEVICES
+		addListToSendAudioMenu( DeviceInfo::mpvPulseDevices(), "pulse");
+		#endif
+
 		#if USE_MPV_WASAPI_DEVICES
 		addListToSendAudioMenu( DeviceInfo::mpvWasapiDevices(), "wasapi");
 		#endif
+
+		#if USE_MPV_COREAUDIO_DEVICES
+		addListToSendAudioMenu( DeviceInfo::mpvCoreaudioDevices(), "coreaudio");
+		#endif
 	}
 #endif
 }
