@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -124,7 +124,7 @@
 
 
 // Adds or not the "Repaint the background of the video window" option.
-#ifndef Q_OS_WIN
+#ifdef OS_UNIX_NOT_MAC
 #define REPAINT_BACKGROUND_OPTION 1
 #endif
 
