@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class EqSlider : public QWidget, public Ui::EqSlider
 	Q_PROPERTY(int value READ value WRITE setValue)
 
 public:
-	EqSlider( QWidget* parent = 0, Qt::WindowFlags f = 0 );
+	EqSlider( QWidget* parent = 0, Qt::WindowFlags f = QFlag(0) );
 	~EqSlider();
 
 public slots:
@@ -41,7 +41,7 @@ public slots:
 
 public:
 	int value() const;
-	const QPixmap * icon() const;
+	QPixmap icon() const;
 	QString label() const;
 
 	QSlider * sliderWidget() { return _slider; };
