@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,8 +42,9 @@ QString FileSettingsHash::configFile(const QString & filename, int type, QString
 		hash = FileHash::calculateHash(filename);
 	} else {
 		QByteArray ba;
-		for (int n = filename.count()-1; n >= 0; --n) {
-			ba += filename.at(n);
+		QByteArray f = filename.toUtf8();
+		for (int n = f.count()-1; n >= 0; --n) {
+			ba += f[n];
 		}
 		//qDebug() << "FileSettingsHash::configFile: ba:" << ba;
 		hash = ba.toBase64();
