@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -108,6 +108,17 @@ MPVProcess::~MPVProcess() {
 #endif
 }
 
+#ifdef USE_IPC
+void MPVProcess::setSocketName(const QString & name) {
+	// Remove old socket
+	if (!socket_name.isEmpty() && QFile::exists(socket_name)) {
+		QFile::remove(socket_name);
+	}
+	socket_name = name;
+	qDebug() << "MPVProcess::setSocketName:" << socket_name;
+}
+#endif
+
 bool MPVProcess::start() {
 	md.reset();
 	notified_mplayer_is_running = false;
@@ -185,7 +196,7 @@ void MPVProcess::initializeRX() {
 
 	rx_playing.setPattern("^Playing:.*|^\\[ytdl_hook\\].*");
 	rx_generic.setPattern("^([A-Z_]+)=(.*)");
-	rx_stream_title.setPattern("icy-title: (.*)");
+	rx_stream_title.setPattern("(?:icy-title: |^ Title: )(.*)");
 	rx_debug.setPattern("^(INFO|METADATA)_.*=\\$.*");
 
 	#if 0
@@ -679,6 +690,10 @@ void MPVProcess::parseLine(QByteArray ba) {
 			}
 			else
 			*/
+			if (tag == "INFO_DEMUX_ROTATION") {
+				emit receivedDemuxRotation(value.toInt());
+			}
+			else
 			if (tag == "INFO_AUDIO_BITRATE") {
 				int bitrate = value.toInt();
 				emit receivedAudioBitrate(bitrate);
