@@ -26,6 +26,7 @@
 
 #define OSD_WITH_TIMER
 //#define USE_OLD_VIDEO_EQ
+#define USE_MPV_STATS
 
 #define USE_FILTER_LABELS
 
@@ -64,7 +65,8 @@ public:
 	void addArgument(const QString & a);
 	void setMedia(const QString & media, bool is_playlist = false);
 	void disableInput();
-	void setFixedOptions();
+	void setPredefinedOptions();
+	void disableConfig();
 	void setOption(const QString & option_name, const QVariant & value = QVariant());
 	void addUserOption(const QString & option);
 	void addVF(const QString & filter_name, const QVariant & value = QVariant());
@@ -281,6 +283,9 @@ private:
 
 #ifdef OSD_WITH_TIMER
 	QTimer * osd_timer;
+	#ifdef USE_MPV_STATS
+	int stats_page;
+	#endif
 #endif
 
 	bool use_osd_in_commands;
