@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class MultilineInputDialog : public QDialog, public Ui::MultilineInputDialog
 	Q_OBJECT
 
 public:
-	MultilineInputDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);
+	MultilineInputDialog(QWidget* parent = 0, Qt::WindowFlags f = QFlag(0));
 	~MultilineInputDialog();
 
 	void setLines(const QStringList & lines);
