@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
 	static QString themesPath();
 	static QString shortcutsPath();
 	static QString qtTranslationPath();
-	static QString doc(QString file, QString locale = QString::null, bool english_fallback = true);
+	static QString doc(QString file, QString locale = QString(), bool english_fallback = true);
 
 	//! Forces to use a different path for the config files
 	static void setConfigPath(QString path);
