@@ -1772,7 +1772,7 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 		#if USE_INFOPROVIDER
 		if ( (get_info) && (QFile::exists(files[n])) ) {
 			data = InfoProvider::getInfo(files[n]);
-			name = data.displayName();
+			name = data.displayName(change_name);
 			duration = data.duration;
 			//qApp->processEvents();
 		}
@@ -1791,7 +1791,7 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 	#endif
 
 	if (new_current_item != -1) setCurrentItem(new_current_item);
-
+	if (shuffleAct->isChecked()) shuffle(true);
 	qDebug() << "Playlist::addFiles: latest_dir:" << latest_dir;
 }
 
@@ -1818,6 +1818,7 @@ void Playlist::addUrls() {
 			if (!u.isEmpty()) addItem( u, "", 0 );
 		}
 		setModified(true);
+		if (shuffleAct->isChecked()) shuffle(true);
 	}
 }
 
