@@ -378,7 +378,11 @@ void Preferences::reset() {
 	time_to_kill_mplayer = 5000;
 
 #ifdef MPRIS2
+	#ifdef Q_OS_LINUX
 	use_mpris2 = true;
+	#else
+	use_mpris2 = false;
+	#endif
 #endif
 
 #ifdef MPV_SUPPORT
@@ -394,6 +398,8 @@ void Preferences::reset() {
 
 	use_native_open_dialog = true;
 
+	disable_player_config = true;
+
 
     /* *********
        GUI stuff
@@ -960,6 +966,8 @@ void Preferences::save() {
 
 	set->setValue("use_native_open_dialog", use_native_open_dialog);
 
+	set->setValue("disable_player_config", disable_player_config);
+
 	set->endGroup(); // advanced
 
 
@@ -1557,6 +1565,8 @@ void Preferences::load() {
 
 	use_native_open_dialog = set->value("use_native_open_dialog", use_native_open_dialog).toBool();
 
+	disable_player_config = set->value("disable_player_config", disable_player_config).toBool();
+
 	set->endGroup(); // advanced
 
 
