@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class PrefInterface : public PrefWidget, public Ui::PrefInterface
 	Q_OBJECT
 
 public:
-	PrefInterface( QWidget * parent = 0, Qt::WindowFlags f = 0 );
+	PrefInterface( QWidget * parent = 0, Qt::WindowFlags f = QFlag(0) );
 	~PrefInterface();
 
 	virtual QString sectionName();
