@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ class ShareWidget : public QWidget
 public:
 	enum Display { Never = 0, Random = 1, Always = 2 };
 
-	ShareWidget(QSettings * settings, QWidget * parent = 0, Qt::WindowFlags f = 0);
+	ShareWidget(QSettings * settings, QWidget * parent = 0, Qt::WindowFlags f = QFlag(0));
 	~ShareWidget();
 
 	virtual void setVisible(bool visible);
