@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -190,8 +190,11 @@ BaseGui * SMPlayer::createGUI(QString gui_name) {
 	connect(gui, SIGNAL(guiChanged(QString)), this, SLOT(changeGUI(QString)));
 #endif
 
-#if SINGLE_INSTANCE
 	MyApplication * app = MyApplication::instance();
+#ifdef Q_OS_MACX
+	connect(app, SIGNAL(openFiles(QStringList)), gui, SLOT(openFiles(QStringList)));
+#endif
+#if SINGLE_INSTANCE
 	connect(app, SIGNAL(messageReceived(const QString&)),
             gui, SLOT(handleMessageFromOtherInstances(const QString&)));
 	app->setActivationWindow(gui);
@@ -600,7 +603,7 @@ void SMPlayer::showInfo() {
 	}
 #endif
 	QString s = QObject::tr("This is SMPlayer v. %1 running on %2")
-            .arg(Version::printable())
+           .arg(Version::printable())
 #ifdef Q_OS_LINUX
            .arg("Linux")
 #else
@@ -610,7 +613,15 @@ void SMPlayer::showInfo() {
 #ifdef Q_OS_OS2
            .arg("eCS (OS/2)")
 #else
-		   .arg("Other OS")
+#ifdef Q_OS_MACX
+           .arg("Mac OS")
+#else
+#ifdef Q_OS_FREEBSD
+           .arg("FreeBSD")
+#else
+           .arg("Another OS")
+#endif
+#endif
 #endif
 #endif
 #endif
@@ -688,7 +699,7 @@ void SMPlayer::myMessageOutput( QtMsgType type, const char *msg ) {
 			fprintf( stderr, "Fatal: %s\n", orig_line.toLocal8Bit().data() );
 			#endif
 			line2 = "FATAL: " + orig_line;
-			abort();                    // deliberately core dump
+			break;
 		case QtCriticalMsg:
 			#ifndef NO_DEBUG_ON_CONSOLE
 			fprintf( stderr, "Critical: %s\n", orig_line.toLocal8Bit().data() );
